@@ -16,19 +16,19 @@
 from __future__ import annotations
 
 import inspect
-import re
 from collections.abc import Callable
 from json.encoder import JSONEncoder
 from typing import IO, Any, Protocol, TypeVar
 
 import orjson
+import regex
 
 _T_co = TypeVar("_T_co", covariant=True)
 
 
 class SupportsRead(Protocol[_T_co]):  # noqa: D101
     # pylint: disable=missing-class-docstring, too-few-public-methods
-    def read(self, __length: int = ...) -> _T_co:
+    def read(self, __length: int = ...) -> _T_co:  # noqa: D102
         # pylint: disable=missing-function-docstring
         ...
 
@@ -95,7 +95,7 @@ def dumps(  # noqa: C901, D103
         if isinstance(indent, int):
             indent = " " * indent
         indent_bytes = str(indent).encode("utf-8")
-        output = re.sub(
+        output = regex.sub(
             rb"(?m)^\s+",
             lambda match: len(match[0]) // 2 * indent_bytes,
             output,
