@@ -17,6 +17,7 @@ from __future__ import annotations
 
 import asyncio
 import io
+import logging
 import os
 import sys
 from asyncio import Future
@@ -35,6 +36,8 @@ from .. import EVENT_SHUTDOWN, NAME
 from ..utils.request_handler import APIRequestHandler
 from ..utils.utils import ModuleInfo, Permission
 
+logger = logging.getLogger(__name__)
+
 
 def get_module_info() -> ModuleInfo:
     """Create and return the ModuleInfo for this module."""
@@ -112,5 +115,7 @@ class UpdateAPI(APIRequestHandler):
             self.flush()
         await self.finish()
         await process.wait()
-        if not process.returncode:
+        if process.returncode:
+            logger.error("Failed to install %s", filename)
+        else:
             EVENT_SHUTDOWN.set()
