@@ -1,4 +1,5 @@
 // @license magnet:?xt=urn:btih:0b31508aeb0634b347b8270c7bee4d411b5d4109&dn=agpl-3.0.txt GNU-AGPL-3.0-or-later
+"use strict";
 
 // these functions break if used the css-only functionality of the site-pane
 function showSitePane() {
@@ -51,7 +52,7 @@ function hideSitePane() {
         let minDiffX = Math.max(
             12,
             0.01 * window.screen.width,
-            diffY * 1.5,
+            diffY * 1.5
         );
 
         console.debug({diffX, minDiffX});
