@@ -42,11 +42,14 @@ def hash_file(path: str | Path) -> str:
 
 def create_file_hashes_dict() -> dict[str, str]:
     """Create a dict of file hashes."""
-    return {
+    file_hashes_dict = {
         str(path).removeprefix(ROOT_DIR): hash_file(path)
         for path in Path(STATIC_DIR).rglob("*")
         if path.is_file() and "img/openmoji-svg-" not in str(path)
     }
+    file_hashes_dict["/favicon.png"] = file_hashes_dict["/static/favicon.png"]
+    file_hashes_dict["/humans.txt"] = file_hashes_dict["/static/humans.txt"]
+    return file_hashes_dict
 
 
 FILE_HASHES_DICT = create_file_hashes_dict()
@@ -145,6 +148,11 @@ def get_handlers() -> list[Handler]:
             StaticFileHandler,
             {"path": STATIC_DIR},
         ),
+        (
+            r"/favicon\.ico",
+            tornado.web.RedirectHandler,
+            {"url": fix_static_path("/favicon.png")},
+        ),
     ]
     if sys.flags.dev_mode:
         # add handlers for the not minified CSS files
@@ -181,21 +189,19 @@ def get_handlers() -> list[Handler]:
 
 
 @cache
-def fix_static_url(url: str) -> str:
-    """Fix the URL for static files."""
-    if not url.startswith("/static/"):
-        url = f"/static/{url}"
-    if "?" in url:
-        url = url.split("?")[0]
-    if url.startswith("/static/img/openmoji-svg-"):
-        return url
-    if url in FILE_HASHES_DICT:
-        hash_ = FILE_HASHES_DICT[url]
-        if url == "/static/favicon.png":
-            return f"/favicon.png?v={hash_}"
-        return f"{url}?v={hash_}"
-    logger.warning("%s not in FILE_HASHES_DICT", url)
-    return url
+def fix_static_path(path: str) -> str:
+    """Fix the path for static files."""
+    if not path.startswith("/"):
+        path = f"/static/{path}"
+    if "?" in path:
+        path = path.split("?")[0]
+    if path.startswith("/static/img/openmoji-svg-"):
+        return path
+    if path in FILE_HASHES_DICT:
+        hash_ = FILE_HASHES_DICT[path]
+        return f"{path}?v={hash_}"
+    logger.warning("%s not in FILE_HASHES_DICT", path)
+    return path
 
 
 class StaticFileHandler(tornado.web.StaticFileHandler):
@@ -258,11 +264,12 @@ class CachedStaticFileHandler(StaticFileHandler):
         pass
 
     @classmethod
-    def make_static_url(
+    def make_static_path(
         cls, settings: dict[str, Any], path: str, include_version: bool = True
     ) -> str:
-        """Make a static url for the given path."""
-        return fix_static_url(path)
+        """Make a static path for the given path."""
+        # pylint: disable=unused-argument
+        return fix_static_path(path)
 
     def set_headers(self) -> None:
         """Set the default headers for this handler."""
