@@ -26,16 +26,18 @@ from datetime import datetime
 from enum import IntFlag
 from functools import cache
 from ipaddress import IPv4Address, IPv6Address, ip_address, ip_network
-from typing import IO, Any, Literal, TypeVar, Union
+from typing import IO, Any, Literal, TypeVar, Union, cast
 from urllib.parse import SplitResult, parse_qsl, urlencode, urlsplit, urlunsplit
 
 import elasticapm  # type: ignore[import]
 import regex
 from blake3 import blake3  # type: ignore[import]
-from elasticsearch import AsyncElasticsearch
-from Levenshtein import distance  # type: ignore[import]
+from editdistance import distance
+from elasticsearch import AsyncElasticsearch, ElasticsearchException
+from geoip import geolite2  # type: ignore[import]
 from redis.asyncio import Redis
 from tornado.web import HTTPError, RequestHandler
+from UltraDict import UltraDict  # type: ignore[import]
 
 from .. import STATIC_DIR
 
@@ -327,6 +329,13 @@ def emoji2code(emoji: str) -> str:
     return "-".join(f"{ord(c):04x}" for c in emoji).upper()
 
 
+def emoji2html(emoji: str) -> str:
+    """Convert an emoji to HTML."""
+    return create_emoji_html(
+        emoji, f"/static/img/openmoji-svg-14.0/{emoji2code(emoji)}.svg"
+    )
+
+
 def emojify(string: str) -> str:
     """Emojify a given string."""
     string = regex.sub(
@@ -352,13 +361,21 @@ async def geoip(
     database: str = "GeoLite2-City.mmdb",
     elasticsearch: None | AsyncElasticsearch = None,
     *,
-    geoip_cache: dict[str, dict[str, dict[str, Any]]] = {},  # noqa: B006
+    allow_fallback: bool = True,
+    caches: dict[str, dict[str, dict[str, Any]]] = UltraDict(),  # noqa: B008
 ) -> None | dict[str, Any]:
     """Get GeoIP information."""
-    if ip not in geoip_cache:
-        geoip_cache[ip] = {}
-    if database not in geoip_cache[ip]:
+    # pylint: disable=too-complex
+    cache = caches.get(ip, {})  # pylint: disable=redefined-outer-name
+    if database not in cache:
         if not elasticsearch:
+            if allow_fallback and database in {
+                "GeoLite2-City.mmdb",
+                "GeoLite2-Country.mmdb",
+            }:
+                return geoip_fallback(
+                    ip, country=database == "GeoLite2-City.mmdb"
+                )
             return None
 
         properties: None | tuple[str, ...]
@@ -384,30 +401,83 @@ async def geoip(
         else:
             properties = None
 
-        geoip_cache[ip][database] = (
-            await elasticsearch.ingest.simulate(
-                body={
-                    "pipeline": {
-                        "processors": [
-                            {
-                                "geoip": {
-                                    "field": "ip",
-                                    "database_file": database,
-                                    "properties": properties,
+        try:
+            cache[database] = (
+                await elasticsearch.ingest.simulate(
+                    body={
+                        "pipeline": {
+                            "processors": [
+                                {
+                                    "geoip": {
+                                        "field": "ip",
+                                        "database_file": database,
+                                        "properties": properties,
+                                    }
                                 }
-                            }
-                        ]
+                            ]
+                        },
+                        "docs": [{"_source": {"ip": ip}}],
                     },
-                    "docs": [{"_source": {"ip": ip}}],
-                },
-                params={"filter_path": "docs.doc._source"},
+                    params={"filter_path": "docs.doc._source"},
+                )
+            )["docs"][0]["doc"]["_source"].get("geoip", {})
+        except ElasticsearchException:
+            if allow_fallback and database in {
+                "GeoLite2-City.mmdb",
+                "GeoLite2-Country.mmdb",
+            }:
+                return geoip_fallback(
+                    ip, country=database == "GeoLite2-City.mmdb"
+                )
+            raise
+        if "country_iso_code" in cache[database]:
+            cache[database]["country_flag"] = country_code_to_flag(
+                cache[database]["country_iso_code"]
             )
-        )["docs"][0]["doc"]["_source"].get("geoip", {})
-        if "country_iso_code" in geoip_cache[ip][database]:
-            geoip_cache[ip][database]["country_flag"] = country_code_to_flag(
-                geoip_cache[ip][database]["country_iso_code"]
-            )
-    return geoip_cache[ip][database]
+        caches[ip] = cache
+    return cache[database]
+
+
+def geoip_fallback(ip: str, country: bool = False) -> None | dict[str, Any]:
+    """Get GeoIP information without using Elasticsearch."""
+    # pylint: disable=invalid-name
+    if not (info := geolite2.lookup(ip)):
+        return None
+
+    info_dict = info.get_info_dict()
+
+    continent_name = info_dict.get("continent", {}).get("names", {}).get("en")
+    country_iso_code = info_dict.get("country", {}).get("iso_code")
+    country_name = info_dict.get("country", {}).get("names", {}).get("en")
+
+    data = {
+        "continent_name": continent_name,
+        "country_iso_code": country_iso_code,
+        "country_name": country_name,
+    }
+
+    if data["country_iso_code"]:
+        data["country_flag"] = country_code_to_flag(data["country_iso_code"])
+
+    if country:
+        for key, value in tuple(data.items()):
+            if not value:
+                del data[key]
+
+        return data
+
+    latitude = info_dict.get("location", {}).get("latitude")
+    longitude = info_dict.get("location", {}).get("longitude")
+    location = (latitude, longitude) if latitude and longitude else None
+    timezone = info_dict.get("location", {}).get("time_zone")
+
+    data.update({"location": location, "timezone": timezone})
+
+    for key, value in tuple(data.items()):
+        if not value:
+            del data[key]
+
+    return data
 
 
 def get_themes() -> tuple[str, ...]:
@@ -439,6 +509,15 @@ def hash_ip(address: str | IPv4Address | IPv6Address) -> str:
     )
 
 
+def is_in_european_union(ip: str) -> None | bool:
+    """Return whether or not the specified address is in the EU."""
+    # pylint: disable=invalid-name
+    if not (info := geolite2.lookup(ip)):
+        return None
+
+    return cast(bool, info.get_info_dict().get("is_in_european_union", False))
+
+
 def length_of_match(match: regex.Match[str]) -> int:
     """Calculate the length of the regex match and return it."""
     span = match.span()
