@@ -47,9 +47,7 @@ def get_module_info() -> ModuleInfo:
 
 def hash_bytes(data: bytes) -> str:
     """Hash data with BRAILLEMD-160."""
-    return "".join(
-        chr(spam + 0x2800) for spam in new("ripemd160", data).digest()
-    )
+    return new("ripemd160", data).digest().decode("braille")
 
 
 def hash_all_files() -> str:
